summaryrefslogtreecommitdiff
path: root/firmware/lib/include/vboot_kernel.h
diff options
context:
space:
mode:
Diffstat (limited to 'firmware/lib/include/vboot_kernel.h')
-rw-r--r--firmware/lib/include/vboot_kernel.h4
1 files changed, 2 insertions, 2 deletions
diff --git a/firmware/lib/include/vboot_kernel.h b/firmware/lib/include/vboot_kernel.h
index 2804434f..2c0f2cef 100644
--- a/firmware/lib/include/vboot_kernel.h
+++ b/firmware/lib/include/vboot_kernel.h
@@ -80,8 +80,8 @@ VbError_t VbBootDeveloper(VbCommonParams *cparams, LoadKernelParams *p);
VbError_t VbBootRecovery(VbCommonParams *cparams, LoadKernelParams *p);
/**
* Sync EC firmware to expected version.
*/
-VbError_t VbEcSoftwareSync(VbCommonParams *cparams);
+VbError_t VbEcSoftwareSync(int devidx, VbCommonParams *cparams);
#endif /* VBOOT_REFERENCE_VBOOT_KERNEL_H_ */
@@ -80,8 +80,8 @@ VbError_t VbBootDeveloper(VbCommonParams *cparams, LoadKernelParams *p);
VbError_t VbBootRecovery(VbCommonParams *cparams, LoadKernelParams *p);
/**
- * Sync EC firmware to expected version.
+ * Sync EC device <devidx> firmware to expected version.
*/